pub trait DecodeQuadSink<D: Decoder + ?Sized>: DecodeSingleSink {
// Required method
fn on_quad(&mut self, quad: D::DecodedQuad, nums_decoded: usize);
}Expand description
Receives numbers decoded via a Decoder in DecodeCursor.decode_sink().
Since stream-vbyte is oriented around groups of 4 numbers, some decoders will expose decoded
numbers in some decoder-specific datatype. Or, if that is not applicable for a particular
Decoder implementation, all decoded numbers will instead be passed to
DecodeSingleSink.on_number().
Required Methods
Sourcefn on_quad(&mut self, quad: D::DecodedQuad, nums_decoded: usize)
fn on_quad(&mut self, quad: D::DecodedQuad, nums_decoded: usize)
nums_decoded is the number of numbers that have already been decoded before this quad
in the current invocation of DecodeCursor.decode_sink().
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".